@@ -13,6 +13,7 @@ const DEFAULT_MAX_BRANCHES: usize = 1_000;
 
 /// Configure a model
 #[derive(Debug)]
+#[non_exhaustive] // Support adding more fields in the future
 pub struct Builder {
     /// Max number of threads to check as part of the execution.
     ///
@@ -64,9 +65,6 @@ pub struct Builder {
     ///
     /// Defaults to existence of `LOOM_LOG` environment variable.
     pub log: bool,
-
-    // Support adding more fields in the future
-    _p: (),
 }
 
 impl Builder {
@@ -77,17 +75,12 @@ impl Builder {
         let checkpoint_interval = env::var("LOOM_CHECKPOINT_INTERVAL")
             .map(|v| {
                 v.parse()
-                    .ok()
                     .expect("invalid value for `LOOM_CHECKPOINT_INTERVAL`")
             })
             .unwrap_or(20_000);
 
         let max_branches = env::var("LOOM_MAX_BRANCHES")
-            .map(|v| {
-                v.parse()
-                    .ok()
-                    .expect("invalid value for `LOOM_MAX_BRANCHES`")
-            })
+            .map(|v| v.parse().expect("invalid value for `LOOM_MAX_BRANCHES`"))
             .unwrap_or(DEFAULT_MAX_BRANCHES);
 
         let location = env::var("LOOM_LOCATION").is_ok();
@@ -96,10 +89,7 @@ impl Builder {
 
         let max_duration = env::var("LOOM_MAX_DURATION")
             .map(|v| {
-                let secs = v
-                    .parse()
-                    .ok()
-                    .expect("invalid value for `LOOM_MAX_DURATION`");
+                let secs = v.parse().expect("invalid value for `LOOM_MAX_DURATION`");
                 Duration::from_secs(secs)
             })
             .ok();
@@ -107,25 +97,16 @@ impl Builder {
         let max_permutations = env::var("LOOM_MAX_PERMUTATIONS")
             .map(|v| {
                 v.parse()
-                    .ok()
                     .expect("invalid value for `LOOM_MAX_PERMUTATIONS`")
             })
             .ok();
 
         let preemption_bound = env::var("LOOM_MAX_PREEMPTIONS")
-            .map(|v| {
-                v.parse()
-                    .ok()
-                    .expect("invalid value for `LOOM_MAX_PREEMPTIONS`")
-            })
+            .map(|v| v.parse().expect("invalid value for `LOOM_MAX_PREEMPTIONS`"))
             .ok();
 
         let checkpoint_file = env::var("LOOM_CHECKPOINT_FILE")
-            .map(|v| {
-                v.parse()
-                    .ok()
-                    .expect("invalid value for `LOOM_CHECKPOINT_FILE`")
-            })
+            .map(|v| v.parse().expect("invalid value for `LOOM_CHECKPOINT_FILE`"))
             .ok();
 
         Builder {
@@ -138,7 +119,6 @@ impl Builder {
             checkpoint_interval,
             location,
             log,
-            _p: (),
         }
     }
 
@@ -223,6 +203,12 @@ impl Builder {
     }
 }
 
+impl Default for Builder {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 /// Run all concurrent permutations of the provided closure.
 ///
 /// Uses a default [`Builder`](crate::model::Builder) which can be affected
